@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -328,7 +328,7 @@ static void cb_ss_set_lock_callback(const struct ofono_error *error,
 	struct ofono_call_barring *cb = data;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		ofono_debug("Enabling/disabling Call Barring via SS failed");
+		DBG("Enabling/disabling Call Barring via SS failed");
 		__ofono_dbus_pending_reply(&cb->pending,
 					__ofono_error_failed(cb->pending));
 		return;
@@ -380,10 +380,10 @@ static gboolean cb_ss_control(int type, const char *sc,
 		return TRUE;
 	}
 
-	ofono_debug("Received call barring ss control request");
+	DBG("Received call barring ss control request");
 
-	ofono_debug("type: %d, sc: %s, sia: %s, sib: %s, sic: %s, dn: %s",
-			type, sc, sia, sib, sic, dn);
+	DBG("type: %d, sc: %s, sia: %s, sib: %s, sic: %s, dn: %s",
+		type, sc, sia, sib, sic, dn);
 
 	fac = cb_ss_service_to_fac(sc);
 	if (!fac)
@@ -490,7 +490,7 @@ static void cb_set_passwd_callback(const struct ofono_error *error, void *data)
 		reply = dbus_message_new_method_return(cb->pending);
 	else {
 		reply = __ofono_error_failed(cb->pending);
-		ofono_debug("Changing Call Barring password via SS failed");
+		DBG("Changing Call Barring password via SS failed");
 	}
 
 	__ofono_dbus_pending_reply(&cb->pending, reply);
@@ -512,9 +512,9 @@ static gboolean cb_ss_passwd(const char *sc,
 		return TRUE;
 	}
 
-	ofono_debug("Received call barring ss password change request");
+	DBG("Received call barring ss password change request");
 
-	ofono_debug("sc: %s", sc);
+	DBG("sc: %s", sc);
 
 	if (!strcmp(sc, ""))
 		fac = "AB";
@@ -728,7 +728,7 @@ static void set_lock_callback(const struct ofono_error *error, void *data)
 	struct ofono_call_barring *cb = data;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		ofono_debug("Enabling/disabling a lock failed");
+		DBG("Enabling/disabling a lock failed");
 		__ofono_dbus_pending_reply(&cb->pending,
 					__ofono_error_failed(cb->pending));
 		return;
@@ -777,8 +777,9 @@ static gboolean cb_lock_property_lookup(const char *property, const char *value,
 	} else if (!strcmp(property, "Incoming")) {
 		start = CB_INCOMING_START;
 		end = CB_INCOMING_END;
-	} else
+	} else {
 		return FALSE;
+	}
 
 	/* Gah, this is a special case.  If we're setting a barring to
 	 * disabled, then generate a disable all outgoing/incoming
@@ -875,7 +876,7 @@ static void disable_all_callback(const struct ofono_error *error, void *data)
 	struct ofono_call_barring *cb = data;
 
 	if (error->type != OFONO_ERROR_TYPE_NO_ERROR) {
-		ofono_debug("Disabling all barring failed");
+		DBG("Disabling all barring failed");
 		__ofono_dbus_pending_reply(&cb->pending,
 					__ofono_error_failed(cb->pending));
 		return;
@@ -990,18 +991,9 @@ static void call_barring_incoming_enabled_notify(int idx, void *userdata)
 	struct ofono_call_barring *cb = userdata;
 	DBusConnection *conn = ofono_dbus_get_connection();
 	const char *path = __ofono_atom_get_path(cb->atom);
-	DBusMessage *signal;
 
-	signal = dbus_message_new_signal(path, OFONO_CALL_BARRING_INTERFACE,
-						"IncomingBarringInEffect");
-
-	if (!signal) {
-		ofono_error("Unable to allocate new %s.IncomingBarringInEffect"
-				" signal", OFONO_CALL_BARRING_INTERFACE);
-		return;
-	}
-
-	g_dbus_send_message(conn, signal);
+	g_dbus_emit_signal(conn, path, OFONO_CALL_BARRING_INTERFACE,
+			"IncomingBarringInEffect", DBUS_TYPE_INVALID);
 }
 
 static void call_barring_outgoing_enabled_notify(int idx, void *userdata)
