@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -59,7 +59,6 @@ struct ofono_modem {
 	guint			interface_update;
 	ofono_bool_t		powered;
 	ofono_bool_t		powered_pending;
-	ofono_bool_t		powered_persistent;
 	guint			timeout;
 	GHashTable		*properties;
 	struct ofono_sim	*sim;
@@ -68,6 +67,7 @@ struct ofono_modem {
 	const struct ofono_modem_driver *driver;
 	void			*driver_data;
 	char			*driver_type;
+	char			*name;
 };
 
 struct ofono_devinfo {
@@ -395,6 +395,10 @@ static DBusMessage *modem_get_properties(DBusConnection *conn,
 
 	g_free(interfaces);
 
+	if (modem->name)
+		ofono_dbus_dict_append(&dict, "Name", DBUS_TYPE_STRING,
+					&modem->name);
+
 	dbus_message_iter_close_container(&iter, &dict);
 
 	return reply;
@@ -452,8 +456,9 @@ static gboolean set_powered_timeout(gpointer user)
 						OFONO_MODEM_INTERFACE,
 						"Powered", DBUS_TYPE_BOOLEAN,
 						&powered);
-	} else
+	} else {
 		modem->powered_pending = modem->powered;
+	}
 
 	if (modem->pending != NULL) {
 		DBusMessage *reply;
@@ -568,24 +573,31 @@ void ofono_modem_set_powered(struct ofono_modem *modem, ofono_bool_t powered)
 	modem->powered_pending = powered;
 
 	if (modem->powered != powered) {
+		dbus_bool_t dbus_powered = powered;
 		modem->powered = powered;
 
-		if (modem->driver) {
-			dbus_bool_t dbus_powered = powered;
+		if (modem->driver == NULL) {
+			ofono_error("Calling ofono_modem_set_powered on a"
+					"modem with no driver is not valid, "
+					"please fix the modem driver.");
+			return;
+		}
 
-			ofono_dbus_signal_property_changed(conn, modem->path,
+		ofono_dbus_signal_property_changed(conn, modem->path,
 						OFONO_MODEM_INTERFACE,
 						"Powered", DBUS_TYPE_BOOLEAN,
 						&dbus_powered);
-		}
 
 		if (powered) {
 			if (modem->driver->pre_sim)
 				modem->driver->pre_sim(modem);
+		} else {
+			remove_all_atoms(modem);
+			modem->call_ids = 0;
 		}
 	}
 
-	if (powering_down) {
+	if (powering_down && powered == FALSE) {
 		modems_remaining -= 1;
 
 		if (modems_remaining == 0)
@@ -874,7 +886,12 @@ void *ofono_devinfo_get_data(struct ofono_devinfo *info)
 	return info->driver_data;
 }
 
-/* Clients only need to free *modems */
+/* Clients only need to free *modems
+ *
+ * Note: this function will never return NULL. It will abort if it
+ * can't allocate memory for *modems; thus even an empty list will
+ * returns a non-NULL pointer.
+ */
 const char **__ofono_modem_get_list()
 {
 	GSList *l;
@@ -1028,17 +1045,40 @@ bool ofono_modem_get_boolean(struct ofono_modem *modem, const char *key)
 	return value;
 }
 
-struct ofono_modem *ofono_modem_create(const char *type)
+void ofono_modem_set_name(struct ofono_modem *modem, const char *name)
+{
+	if (modem->name)
+		g_free(modem->name);
+
+	modem->name = g_strdup(name);
+
+	if (modem->driver) {
+		DBusConnection *conn = ofono_dbus_get_connection();
+
+		ofono_dbus_signal_property_changed(conn, modem->path,
+						OFONO_MODEM_INTERFACE,
+						"Name", DBUS_TYPE_STRING,
+						&modem->name);
+	}
+}
+
+struct ofono_modem *ofono_modem_create(const char *name, const char *type)
 {
 	struct ofono_modem *modem;
 	char path[128];
 
-	DBG("%s", type);
+	DBG("name: %s, type: %s", name, type);
 
 	if (strlen(type) > 16)
 		return NULL;
 
-	snprintf(path, sizeof(path), "/%s%d", type, next_modem_id);
+	if (name && strlen(name) > 64)
+		return NULL;
+
+	if (name == NULL)
+		snprintf(path, sizeof(path), "/%s%d", type, next_modem_id);
+	else
+		snprintf(path, sizeof(path), "/%s", name);
 
 	if (__ofono_dbus_valid_object_path(path) == FALSE)
 		return NULL;
@@ -1055,7 +1095,8 @@ struct ofono_modem *ofono_modem_create(const char *type)
 
 	g_modem_list = g_slist_prepend(g_modem_list, modem);
 
-	next_modem_id += 1;
+	if (name == NULL)
+		next_modem_id += 1;
 
 	return modem;
 }
@@ -1159,13 +1200,6 @@ int ofono_modem_register(struct ofono_modem *modem)
 					OFONO_ATOM_TYPE_SIM,
 					sim_watch, modem, NULL);
 
-	/* TODO: Read powered property from store */
-	if (modem->powered_persistent)
-		set_powered(modem, TRUE);
-
-	if (modem->powered == TRUE && modem->driver->pre_sim)
-		modem->driver->pre_sim(modem);
-
 	return 0;
 }
 
