@@ -42,6 +42,7 @@
 #include "smsutil.h"
 #include "simutil.h"
 #include "storage.h"
+#include "stkutil.h"
 
 #define SIM_MANAGER_INTERFACE "org.ofono.SimManager"
 
@@ -1506,7 +1507,7 @@ static gboolean sim_op_check_cached(struct ofono_sim *sim)
 
 	if (fd == -1) {
 		if (errno != ENOENT)
-			ofono_debug("Error %i opening cache file for "
+			DBG("Error %i opening cache file for "
 					"fileid %04x, IMSI %s",
 					errno, op->id, imsi);
 
@@ -1810,7 +1811,7 @@ static void sim_cb_download_cb(const struct ofono_error *error,
 		return;
 	}
 
-	ofono_debug("CellBroadcast download to UICC reported no error");
+	DBG("CellBroadcast download to UICC reported no error");
 }
 
 void __ofono_cbs_sim_download(struct ofono_sim *sim,
@@ -1824,7 +1825,7 @@ void __ofono_cbs_sim_download(struct ofono_sim *sim,
 	if (sim->driver->envelope == NULL)
 		return;
 
-	tlv[0] = 0xd2; /* Cell Broadcast Download */
+	tlv[0] = STK_ENVELOPE_TYPE_CBS_PP_DOWNLOAD;
 	tlv[1] = 6 + pdu_len;
 	tlv[2] = 0x82; /* Device Identities */
 	tlv[3] = 0x02; /* Device Identities length */
